@@ -58,7 +58,7 @@ class DipDupCodeGenerator:
         self._logger.info('Creating package `%s`', self._config.package)
         try:
             package_path = self._config.package_path
-        except (ImportError, ModuleNotFoundError):
+        except ImportError:
             package_path = join(os.getcwd(), self._config.package)
             mkdir(package_path)
             with open(join(package_path, '__init__.py'), 'w'):
@@ -80,6 +80,17 @@ class DipDupCodeGenerator:
             with open(join(handlers_path, '__init__.py'), 'w'):
                 pass
 
+        self._logger.info('Creating `%s/sql` directory', self._config.package)
+        sql_path = join(self._config.package_path, 'sql')
+        with suppress(FileExistsError):
+            mkdir(sql_path)
+        sql_on_restart_path = join(sql_path, 'on_restart')
+        with suppress(FileExistsError):
+            mkdir(sql_on_restart_path)
+        sql_on_reindex_path = join(sql_path, 'on_reindex')
+        with suppress(FileExistsError):
+            mkdir(sql_on_reindex_path)
+
     async def fetch_schemas(self) -> None:
         """Fetch JSONSchemas for all contracts used in config"""
         self._logger.info('Creating `schemas` package')
@@ -224,6 +235,7 @@ class DipDupCodeGenerator:
                 if root.split('/')[-1] == 'parameter':
                     name += '_parameter'
 
+                name = snake_to_pascal(name)
                 self._logger.info('Generating type `%s`', name)
                 args = [
                     'datamodel-codegen',
@@ -232,7 +244,7 @@ class DipDupCodeGenerator:
                     '--output',
                     output_path,
                     '--class-name',
-                    snake_to_pascal(name),
+                    name,
                     '--disable-timestamp',
                     '--use-default',
                 ]
