@@ -19,7 +19,7 @@ from dipdup.config import (
 from dipdup.context import HandlerContext
 from dipdup.datasources.tzkt.datasource import BigMapFetcher, OperationFetcher, TzktDatasource
 from dipdup.models import BigMapAction, BigMapData, BigMapDiff, OperationData, Origination, State, TemporaryState, Transaction
-from dipdup.utils import FormattedLogger, in_global_transaction, reindex
+from dipdup.utils import FormattedLogger, in_global_transaction
 
 OperationGroup = namedtuple('OperationGroup', ('hash', 'counter'))
 
@@ -82,7 +82,7 @@ class Index:
 
         elif state.hash != index_hash:
             self._logger.warning('Config hash mismatch, reindexing')
-            await reindex()
+            await self._ctx.reindex()
 
         self._state = state
 
@@ -189,7 +189,6 @@ class OperationIndex(Index):
                 operation_groups[key] = []
             operation_groups[key].append(operation)
 
-        keys = list(operation_groups.keys())
         for operation_group, operations in operation_groups.items():
             self._logger.debug('Matching %s', key)
 
